==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/flipgroup/resource_flipgroup/main.tf <==
/*
Пример использования
Работа с ресурсом flipgroup (группа с плавающим ip-адресом)
Ресурс позволяет:
1. Создавать flipgroup
2. Редактировать flipgroup
3. Удалять flipgroup
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*

terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "dynamix_flipgroup" "fg" {
  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 999

  #наименование Flipgroup
  #обязательный параметр
  #тип - строка
  name = "flipgroup_name"

  #тип сети (EXTNET, ViNS)
  #обязательный параметр
  #тип - строка
  net_type = "EXTNET"

  #id сети
  #обязательный параметр
  #тип - целое число
  net_id = 13

  #тип клиентов (в данный момент поддерживается только тип 'compute')
  #обязательный параметр
  #тип - строка
  client_type = "compute"

  #ip-адрес
  #опциональный параметр
  #тип - строка
  ip = "127.0.0.1"

  #список клиентов, прикрепленных к флипгруппе
  #опциональный параметр
  #тип - массив целых чисел
  client_ids = [11269]

  #описание флипгруппы
  #опциональный параметр
  #тип - строка
  desc = "CHANGED"
}

output "fg_out" {
  value = dynamix_flipgroup.fg
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/flipgroup/resource_flipgroup/main.tf <==
/*
Пример использования
Работа с ресурсом flipgroup (группа с плавающим ip-адресом)
Ресурс позволяет:
1. Создавать flipgroup
2. Редактировать flipgroup
3. Удалять flipgroup
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*

terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "dynamix_flipgroup" "fg" {
  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 999

  #наименование Flipgroup
  #обязательный параметр
  #тип - строка
  name = "flipgroup_name"

  #тип сети (EXTNET, ViNS)
  #обязательный параметр
  #тип - строка
  net_type = "EXTNET"

  #id сети
  #обязательный параметр
  #тип - целое число
  net_id = 13

  #тип клиентов (в данный момент поддерживается только тип 'compute')
  #обязательный параметр
  #тип - строка
  client_type = "compute"

  #ip-адрес
  #опциональный параметр
  #тип - строка
  ip = "127.0.0.1"

  #список клиентов, прикрепленных к флипгруппе
  #опциональный параметр
  #тип - массив целых чисел
  client_ids = [11269]

  #описание флипгруппы
  #опциональный параметр
  #тип - строка
  desc = "CHANGED"
}

output "fg_out" {
  value = dynamix_flipgroup.fg
}
